# $Id: socat.spec,v 1.1 2016/08/03 16:57:34 repoman Exp repoman $
# Authority: dag
# Upstream: <socat$dest-unreach,org>

Summary: Relay for bidirectional data transfer between 2 channels
Name: socat
Version: 1.7.3.0
Release: 1%{?dist}
License: GPL
Group: Applications/Internet
URL: http://www.dest-unreach.org/socat/

Packager: Lawrence R. Rogers <lrr@cert.org>
Vendor: CERT Linux Forensics Tools Repository (LFTR) http://www.cert.org/forensics/repository

Source: http://www.dest-unreach.org/socat/download/socat-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: readline-devel, openssl-devel
Requires: tcp_wrappers

%description
socat is a relay for bidirectional data transfer between two independent data
channels. Each of these data channels may be a file, pipe, device (serial line
etc. or a pseudo terminal), a socket (UNIX, IP4, IP6 - raw, UDP, TCP), an
SSL socket, proxy CONNECT connection, a file descriptor (stdin etc.), the GNU
line editor, a program, or a combination of two of these.

%prep
%setup

%build
%configure --disable-fips
%{__make} %{?_smp_mflags}

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR="%{buildroot}"

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc BUGREPORTS CHANGES COPYING* DEVELOPMENT EXAMPLES FAQ FILES PORTING README SECURITY
%doc *.sh doc/*.css doc/*.help doc/*.html
%doc %{_mandir}/man1/socat.1*
%{_bindir}/filan
%{_bindir}/procan
%{_bindir}/socat

%changelog
* Wed Aug  3 2016 Lawrence R. Rogers <lrr@cert.org> - 1.7.3.0-1
* Release 1.7.3.0
security:
	(CVE Id pending)
	Fixed problems with signal handling caused by use of not async signal
	safe functions in signal handlers that could freeze socat, allowing
	denial of service attacks.
	Many changes in signal handling and the diagnostic messages system were
	applied to make the code async signal safe but still provide detailled
	logging from signal handlers:
	Coded function vsnprintf_r() as async signal safe incomplete substitute
	of libc vsnprintf()
	Coded function snprinterr() to replace %m in strings with a system error
	message
	Instead of gettimeofday() use clock_gettime() when available
	Pass Diagnostic messages from signal handler per unix socket to the main
	program flow
	Use sigaction() instead of signal() for better control
	Turn off nested signal handler invocations
	Thanks to Peter Lobsinger for reporting and explaining this issue.

	Red Hat issue 1019975: add TLS host name checks
	OpenSSL client checks if the server certificates names in
	extensions/subjectAltName/DNS or in subject/commonName match the name
	used to connect or the value of the openssl-commonname option.
	Test: OPENSSL_CN_CLIENT_SECURITY

	OpenSSL server checks if the client certificates names in
	extensions/subjectAltNames/DNS or subject/commonName match the value of
	the openssl-commonname option when it is used.
	Test: OPENSSL_CN_SERVER_SECURITY

	Red Hat issue 1019964: socat now uses the system certificate store with
	OPENSSL when neither options cafile nor capath are used

	Red Hat issue 1019972: needs to specify OpenSSL cipher suites
	Default cipherlist is now "HIGH:-NULL:-PSK:-aNULL" instead of empty to
	prevent downgrade attacks

new features:
	OpenSSL addresses set couple of environment variables from values in
	peer certificate, e.g.: 
	SOCAT_OPENSSL_X509_SUBJECT, SOCAT_OPENSSL_X509_ISSUER,
	SOCAT_OPENSSL_X509_COMMONNAME, 
	SOCAT_OPENSSL_X509V3_SUBJECTALTNAME_DNS
	Tests: ENV_OPENSSL_{CLIENT,SERVER}_X509_*

	Added support for methods TLSv1, TLSv1.1, TLSv1.2, and DTLS1
	Tests: OPENSSL_METHOD_*

	Enabled OpenSSL server side use of ECDHE ciphers. Feature suggested
	by Andrey Arapov.

	Added a new option termios-rawer for ptys.
	Thanks to Christian Vogelgsang for pointing me to this requirement

corrections:
	Bind with ABSTRACT commands used non-abstract namespace (Linux).
	Test: ABSTRACT_BIND
	Thanks to Denis Shatov for reporting this bug.

	Fixed return value of nestlex()

	Option ignoreeof on the right address hung.
	Test: IGNOREEOF_REV
	Thanks to Franz Fasching for reporting this bug.

	Address SYSTEM, when terminating, shut down its parent addresses,
	e.g. an SSL connection which the parent assumed to still be active.
	Test: SYSTEM_SHUTDOWN

	Passive (listening or receiving) addresses with empty port field bound
	to a random port instead of terminating with error.
	Test: TCP4_NOPORT

	configure with some combination of disable options produced config
	files that failed to compile due to missing IPPROTO_TCP.
	Thanks to Thierry Fournier for report and patch.

	fixed a few minor bugs with OpenSSL in configure and with messages

	Socat did not work in FIPS mode because 1024 instead of 512 bit DH prime
	is required. Thanks to Zhigang Wang for reporting and sending a patch.

	Christophe Leroy provided a patch that fixes memory leaks reported by
	valgrind

	Help for filan -L was bad, is now corrected to:
	"follow symbolic links instead of showing their properties"

	Address options fdin and fdout were silently ignored when not applicable
	due to -u or -U option. Now these combinations are caught as errors.
	Test: FDOUT_ERROR
	Issue reported by Hendrik.

	Added option termios-cfmakeraw that calls cfmakeraw() and is preferred
	over option raw which is now obsolote. On SysV systems this call is
	simulated by appropriate setting.
	Thanks to Youfu Zhang for reporting issue with option raw.

porting:
	Socat included <sys/poll.h> instead of POSIX <poll.h>
	Thanks to John Spencer for reporting this issue.

	Version 1.7.2.4 changed the check for gcc in configure.ac; this
	broke cross compiling. The particular check gets reverted.
	Thanks to Ross Burton and Danomi Manchego for reporting this issue.

	Debian Bug#764251: Set the build timestamp to a deterministic time:
	support external BUILD_DATE env var to allow to build reproducable
	binaries

	Joachim Fenkes provided an new adapted spec file.

	Type bool and macros Min and Max are defined by socat which led to
	compile errors when they were already provided by build framework.
	Thanks to Liyu Liu for providing a patch.

	David Arnstein contributed a patch for NetBSD 5.1 including stdbool.h
	support and appropriate files in Config/

	Lauri Tirkkonen contributed a patch regarding netinet/if_ether.h
	on Illumos

	Changes for Openindiana: define _XPG4_2, __EXTENSIONS__,
	_POSIX_PTHREAD_SEMANTICS; and minor changes

	Red Hat issue 1182005: socat 1.7.2.4 build failure missing
	linux/errqueue.h
	Socat failed to compile on on PPC due to new requirements for
	including <linux/errqueue.h> and a weakness in the conditional code.
	Thanks to Michel Normand for reporting this issue.

doc:
	In the man page the PTY example was badly formatted. Thanks to
	J.F.Sebastian for sending a patch.

	Added missing CVE ids to security issues in CHANGES

testing:
	Do not distribute testcert.conf with socat source but generate it
	(and new testcert6.conf) during test.sh run.

* Wed Aug  3 2016 Lawrence R. Rogers <lrr@cert.org> - 1.7.2.4-1.1
- Rebuilt for the CERT Linux Forensics Tools Repository (LFTR)

* Fri Jun 08 2012 Dag Wieers <dag@wieers.com> - 1.7.2.1-1
- Updated to release 1.7.2.1.

* Mon Aug 02 2010 Dag Wieers <dag@wieers.com> - 1.7.1.3-1
- Updated to release 1.7.1.3.

* Mon Jan 11 2010 Dag Wieers <dag@wieers.com> - 1.7.1.2-1
- Updated to release 1.7.1.2.

* Sun May 10 2009 Dag Wieers <dag@wieers.com> - 1.7.1.1-1
- Updated to release 1.7.1.1.

* Fri Apr 03 2009 Dag Wieers <dag@wieers.com> - 1.7.1.0-1
- Updated to release 1.7.1.0.

* Sat Nov 08 2008 Dag Wieers <dag@wieers.com> - 1.7.0.0-1
- Updated to release 1.7.0.0.

* Sun Feb 10 2008 Dag Wieers <dag@wieers.com> - 1.6.0.1-1
- Updated to release 1.6.0.1.

* Sat Mar 10 2007 Dag Wieers <dag@wieers.com> - 1.6.0.0-1
- Updated to release 1.6.0.0.

* Wed Jul 19 2006 Dag Wieers <dag@wieers.com> - 1.5.0.0-1
- Updated to release 1.5.0.0.

* Tue Jan 31 2006 Dag Wieers <dag@wieers.com> - 1.4.3.1-1
- Updated to release 1.4.3.1.

* Sun Sep 11 2005 Dag Wieers <dag@wieers.com> - 1.4.3.0-1
- Updated to release 1.4.3.0.

* Sat Mar 19 2005 Dag Wieers <dag@wieers.com> - 1.4.2.0-1
- Updated to release 1.4.2.0.

* Sun Nov 14 2004 Dag Wieers <dag@wieers.com> - 1.4.0.3-1
- Updated to release 1.4.0.3.

* Sat Sep 25 2004 Dag Wieers <dag@wieers.com> - 1.4.0.2-1
- Updated to release 1.4.0.2.

* Thu Jun 24 2004 Dag Wieers <dag@wieers.com> - 1.4.0.0-1
- Updated to release 1.4.0.0.

* Mon Mar 22 2004 Dag Wieers <dag@wieers.com> - 1.3.2.2-1
- Initial package. (using DAR)
